# Available rpmbuild options:
#
# --without	libwrap
# --without	bcrelay
#

%{!?_hardened_build:%global _hardened_build 1}

%if %{?_hardened_build:%{_hardened_build}}%{!?_hardened_build:0}
%global harden -Wl,-z,relro,-z,now
%endif

Summary:		PoPToP Point to Point Tunneling Server
Name:			pptpd
Version:		1.4.0
Release:		%mkrel 3
License:		GPLv2+ and LGPLv2+
Group:			System/Servers
URL:			http://poptop.sourceforge.net/
Source0:		http://downloads.sf.net/poptop/pptpd-%{version}.tar.gz
Source2:		pptpd.sysconfig
Source3:	    pptpd-modules-load.conf
Source4:	    20-pptpd.conf
Patch0:			pptpd-1.4.0-bcrelay-iflog-size-limit.patch
Patch1:			pptpd-initd.patch
Patch2:			pptpd-1.4.0-ppp250-api.patch

%global pppver %((%{__awk} '/^#define PPPD_VERSION/ { print $NF }' /usr/include/pppd/pppdconf.h 2>/dev/null||echo none)|/usr/bin/tr -d '"')

BuildRequires:		ppp-devel > 2.4.9
Requires:			ppp >= %{pppver}
Requires:			perl
Requires(post):		/sbin/chkconfig
Requires(preun):	/sbin/chkconfig
Requires(preun):	/sbin/service

%if %{?_without_libwrap:0}%{!?_without_libwrap:1}
BuildRequires:	tcp_wrappers-devel
%endif

%description
This implements a Virtual Private Networking Server (VPN) that is
compatible with Microsoft VPN clients. It allows windows users to
connect to an internal firewalled network using their dialup.

%prep
%setup -q -n %{name}-%{version}
%apply_patches
perl -pi -e 's,/usr/lib/pptpd,%{_libdir}/pptpd,;' pptpctrl.c

%build
%configure \
	%{!?_without_libwrap:--with-libwrap} \
	%{?_without_libwrap:--without-libwrap} \
	%{!?_without_bcrelay:--enable-bcrelay} \
	%{?_without_bcrelay:--disable-bcrelay}
(echo '#undef VERSION'; echo '#include <pppd/pppdconf.h>') >> plugins/patchlevel.h
make CFLAGS='-fno-builtin -fPIC -DSBINDIR=\"%{_sbindir}\" %{optflags} %{?harden}'

%install
mkdir -p %{buildroot}%{_sysconfdir}/rc.d/init.d
mkdir -p %{buildroot}%{_sysconfdir}/ppp
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man{5,8}
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig

make %{?_smp_mflags} \
	DESTDIR=%{buildroot} \
	INSTALL="install -p" \
	LIBDIR=%{buildroot}%{_libdir}/pptpd \
	install
install -pm 0755 pptpd.init %{buildroot}%{_sysconfdir}/rc.d/init.d/pptpd
install -pm 0644 samples/pptpd.conf %{buildroot}%{_sysconfdir}/pptpd.conf
install -pm 0644 samples/options.pptpd %{buildroot}%{_sysconfdir}/ppp/options.pptpd
install -pm 0755 tools/vpnuser %{buildroot}%{_bindir}/vpnuser
install -pm 0755 tools/vpnstats.pl %{buildroot}%{_bindir}/vpnstats.pl
install -pm 0755 tools/pptp-portslave %{buildroot}%{_sbindir}/pptp-portslave
install -pm 0644 pptpd.conf.5 %{buildroot}%{_mandir}/man5/pptpd.conf.5
install -pm 0644 pptpd.8 %{buildroot}%{_mandir}/man8/pptpd.8
install -pm 0644 pptpctrl.8 %{buildroot}%{_mandir}/man8/pptpctrl.8
install -pm 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/pptpd
install -Dpm 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/modprobe.preload.d/pptpd-load-modules
install -Dpm 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysctl.d/20-pptpd.conf

%post
/sbin/chkconfig --add pptpd >/dev/null 2>&1 ||:

%preun
if [ "$1" = 0 ]; then
    %{_initrddir}/pptpd stop >/dev/null 2>&1 ||:
    /sbin/chkconfig --del pptpd >/dev/null 2>&1 ||:
fi

%postun
[ "$1" -ge 1 ] && %{_initrddir}/pptpd condrestart >/dev/null 2>&1 ||:

%files
%doc AUTHORS COPYING README* TODO ChangeLog* samples
%{_sbindir}/pptpd
%{_sbindir}/pptpctrl
%{_sbindir}/pptp-portslave
%{!?_without_bcrelay:%{_sbindir}/bcrelay}
%dir %{_libdir}/pptpd
%{_libdir}/pptpd/pptpd-logwtmp.so
%{_bindir}/vpnuser
%{_bindir}/vpnstats.pl
%{_mandir}/man5/pptpd.conf.5*
%{_mandir}/man8/*.8*
%attr(0755,root,root) %{_sysconfdir}/rc.d/init.d/pptpd
%config(noreplace) %{_sysconfdir}/sysconfig/pptpd
%config(noreplace) %{_sysconfdir}/pptpd.conf
%config(noreplace) %{_sysconfdir}/ppp/options.pptpd
%config(noreplace) %{_sysconfdir}/modprobe.preload.d/pptpd-load-modules
%config(noreplace) %{_sysconfdir}/sysctl.d/20-pptpd.conf

%changelog
* Wed Jul 12 2023 yodelu - 1.4.0-3pclos2023
- rebuild against ppp-2.5.0

* Tue Mar 23 2021 tex - 1.4.0-2pclos2021
- rebuild against updates

* Fri Feb 12 2021 yodelu 1.4.0-4pclos2021
- imported
